#
# spec file for package glucat
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?suse_version} <= 1500
%global _with_pdfdoc 1
%else
%global _with_pdfdoc 0
%endif

Name:           glucat
Version:        0.8.2
Release:        lp152.5.6
Summary:        Library of C++ templates implementing universal Clifford algebras
License:        LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            http://glucat.sourceforge.net/
Source:         http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM glucat-disable-pdf-doc.patch badshah400@gmail.com -- Disable building pdf documentation until issues with TeXLive 2018 are sorted.
Patch0:         glucat-disable-pdf-doc.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz-gd
BuildRequires:  graphviz-gnome
BuildRequires:  libtool
BuildRequires:  python-Cython
BuildRequires:  python-devel
BuildRequires:  python-numpy
BuildRequires:  libboost_headers-devel
%if %{with pdfdoc}
BuildRequires:  texlive-collection-fontsrecommended
BuildRequires:  texlive-latex-bin
BuildRequires:  texlive-metafont-bin
BuildRequires:  tex(adjustbox.sty)
BuildRequires:  tex(caption.sty)
BuildRequires:  tex(colortbl.sty)
BuildRequires:  tex(fancyhdr.sty)
BuildRequires:  tex(float.sty)
BuildRequires:  tex(helvet.sty)
BuildRequires:  tex(multirow.sty)
BuildRequires:  tex(natbib.sty)
BuildRequires:  tex(sectsty.sty)
BuildRequires:  tex(tabu.sty)
BuildRequires:  tex(tocloft.sty)
BuildRequires:  tex(wasysym.sty)
BuildRequires:  tex(xtab.sty)
%endif

%description
GluCat is a library of template classes which model the universal
Clifford algebras over the field of real numbers, with arbitrary
dimension and arbitrary signature. GluCat implements a model of each
Clifford algebra corresponding to each non-degenerate quadratic form
up to a maximum number of dimensions.

%package devel
Summary:        Library of C++ templates implementing universal Clifford algebras
Group:          Development/Libraries/C and C++
Recommends:     %{name}-doc = %{version}

%description devel
GluCat is a library of template classes which model the universal
Clifford algebras over the field of real numbers, with arbitrary
dimension and arbitrary signature. GluCat implements a model of each
Clifford algebra corresponding to each non-degenerate quadratic form
up to a maximum number of dimensions.

This package contains the header files required for developing
applications using the glucat library.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML

%description doc
GluCat is a library of template classes which model the universal
Clifford algebras over the field of real numbers, with arbitrary
dimension and arbitrary signature. GluCat implements a model of each
Clifford algebra corresponding to each non-degenerate quadratic form
up to a maximum number of dimensions.

This package provides the documentation for %{name}.

%package -n python-glucat
Summary:        Library of C++ templates implementing universal Clifford algebras
Group:          Development/Libraries/C and C++
Requires:       python-base = %{py_ver}
Recommends:     %{name}-doc = %{version}

%description -n python-glucat
GluCat is a library of template classes which model the universal
Clifford algebras over the field of real numbers, with arbitrary
dimension and arbitrary signature. GluCat implements a model of each
Clifford algebra corresponding to each non-degenerate quadratic form
up to a maximum number of dimensions.

This package contains the python-bindings for the package.

%prep
%setup -q
%if ! %{with pdfdoc}
%patch0 -p1
%endif

%build
autoreconf -fvi
sed -i "s|-march=native||g" configure
%configure --prefix=%{_prefix} --docdir=%{_docdir}/%{name} --with-demo-dir=%{_docdir}/%{name}/demos

# FIX A NON-UNIX EOF ENCODING
sed -i 's/\r$//' ./pyclical/demos/plotting_demo_mayavi.py

make %{?_smp_mflags} clean all
make %{?_smp_mflags} doc

%install
%make_install
make DESTDIR=%{buildroot} install-doc

# REMOVE FILES PKGED USING %%doc ANYWAY OR OTHERWISE NOT NEEDED
rm -fr %{buildroot}%{_docdir}/%{name}/{AUTHORS,COPYING,ChangeLog,glucat.lsm,INSTALL,NEWS,README,TODO}

%check
make %{?_smp_mflags} check

%fdupes %{buildroot}%{_docdir}/%{name}/html/

%files devel
%license COPYING
%doc AUTHORS ChangeLog README TODO NEWS
%{_includedir}/%{name}/

%files doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/html/
%if %{with pdfdoc}
%{_docdir}/%{name}/pdf/
%endif

%files -n python-glucat
%{python_sitearch}/*
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/demos/

%changelog
* Sun Feb 10 2019 Atri Bhattacharya <badshah400@gmail.com>
- Add glucat-disable-pdf-doc.patch to disable building pdf
  documentation until issues are fixed.
- Use %%%%license to install COPYING file.
* Tue Jul 10 2018 bwiedemann@suse.com
- make compilation independent of build system CPU (boo#1100520)
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Jul 11 2016 badshah400@gmail.com
- Update to version 0.8.2:
  + The GluCat classes basis_matrix_t and framed_multi<> have been
    refined.
  + The class basis_matrix_t is now based on int rather than on
    Scalar_T. This should make basis matrix generation more
    efficient, especially when Scalar_T is of class dd_real or
    qd_real.
  + The class framed_multi<> is now based on either
    map<index_set_t, Scalar_T> or unordered_map<index_set_t,
    Scalar_T>, rather than the previous base class, map<const
    index_set_t, Scalar_T> or unordered_map<const index_set_t,
    Scalar_T>.  This is for compatibility with the libc++
    implementations of these bases classes.
  + The framed_multi<> and matrix_multi<> constructors that use
    the parameters val, frm and prechecked have changed. The frame
    used for the constuction now includes the union of val.frame()
    with frm, and these constructors no longer throw an exception
    if val is oustide of frm.
  + A new function, reframe(lhs,rhs,lhs_reframed,rhs_reframed)
    fixes a bug in reframing for binary operations on class
    matrix_multi<>.
  + The function reframe(self, ixt) in pyclical/PyCliCal.pyx now
    puts self into a larger frame, containing the union of
    self.frame() and index set ixt.
  + GluCat now compiles with clang++ and libc++.
  + PyClical can now be built with g++ version 4.8 and possibly
    earlier versions.
  + GluCat also compiles cleanly with Intel C++ 16.0.2.
- Drop patches incorporated upstream:
  + glucat-pyclical-demos-dir.patch
  + glucat-doxygen-build-workaround.patch
  + glucat-pyclical-pythonpath.patch.
- Pyclical module now builds with gcc older than 4.9 again,
  reenable python-glucat for openSUSE 13.2 and older.
* Thu May  5 2016 badshah400@gmail.com
- Update to version 0.8.1:
  + The configuration option --with-tuning=arg controls test
    tuning via preprocessor macros and the header files
    test/tuning.h and test/undefine.h.
  + The configuration option --enable-check-isnan controls checks
    for NaN values, and the configuration option --with-pool-alloc
    controls the use of the Boost pool allocator.
  + The scripts test/test-all-config-options.sh,
    test/diff-all-config-outputs.sh and
    test/copy-all-config-outputs.sh enable comprehensive tesing of
    configuation options.
  + The use of Autotools has again been improved, with
    enhancements to make, make clean, make dist and make install,
    and the introduction of make check, make doc and make
    install-doc.
- Use make check for the %%check section.
- Add glucat-pyclical-demos-dir.patch to add a configure option
  "--with-demo-dir" to set a custom path to install the
  pyclical demos (defaults to %%%%{_datadir}/pyclical/demos);
  patch submitted upstream. We use this option to install the
  demos to %%{_docdir}/%%{name}/demos.
- Add glucat-doxygen-build-workaround.patch: required to
  circumvent a known doxygen 1.8.11 regression (bgo#762982); only
  required for openSUSE > 13.2. This patch should be dropped when
  the upstream doxygen bug is fixed and the fixed version is made
  available for openSUSE:Factory.
- Add glucat-pyclical-pythonpath.patch to include the correct dir
  for the Pycilcal module before building the pyclical notebooks;
  patch sent upstream.
- Add BuildRequires: automake, autoconf; new patches modify
  autotool build files.
- Package pyclical demos.
- Pyclical module does not build for openSUSE <= 13.2 or Leap
  42.1.
- Build HTML and PDF documentation, package them in a separate
  sub-package; add BuildRequires on texlive packages required for
  building the PDF documentation.
* Sun Oct 18 2015 schwab@suse.de
- Clean junk before building
* Thu Sep 10 2015 badshah400@gmail.com
- Update to version 0.8.0:
  + Drop all deprecated options (breaks backward compatibility):
  - <ext/hash_map> (was enabled by the option
    _GLUCAT_USE_GNU_CXX_HASH_MAP).
  - <backward/hash_map> (_GLUCAT_USE_BACKWARD_HASH_MAP).
  - <tr1/unordered_map> (_GLUCAT_USE_TR1_UNORDERED_MAP).
  - <tr1/random> (the old default: the option
    _GLUCAT_USE_STD_RANDOM is no longer needed, and is ignored,
    as <random> is now the default).
  - <alglib/evd.h> (_GLUCAT_USE_ALGLIB).
  - <boost/numeric/bindings/lapack/gees.hpp>
    (_GLUCAT_USE_BINDINGS_V1).
* Sat Sep  5 2015 badshah400@gmail.com
- Update to version 0.7.5:
  + The use of Autotools in configuring, building and installing
    GluCat and PyClical has been simplified and improved.
  + Deprecated configuation options have been dropped.
  + The default for --with-random is now std.
  + The default for --with-map is now stdunordered.
- Remove glucat-fix-32bit-build.patch: fixed upstream.
* Sat Dec 27 2014 badshah400@gmail.com
- Update to version 0.7.4:
  + Improved precision of the sqrt, log and exp functions.
- Workaround incorrect install location of pyclical module.
* Thu Apr  3 2014 badshah400@gmail.com
- Update to version 0.7.3:
  + Fixes a bug where the line print_exec("from PyClical import*")
    was left out of some of the pyclical_tutorial*.py files.
* Mon Mar 31 2014 badshah400@gmail.com
- Update to version 0.7.2:
  + When used with PyClical now generates IPython notebooks
  + The Pyclical tutorials are now accompanied by corresponding
    IPython notebooks.
  + The nork() function in matrix.h and matrix_imp.h is now
    accompanied by the signed_perm_nork() function, which is
    faster for the case used by fast<>() in matrix_mult_imp.h
  + Use of the Boost pool allocator with framed_multi<> is now
    optional, controlled via the new symbol
    _GLUCAT_USE_BOOST_POOL_ALLOC
  + GluCat compiles cleanly with g++ 4.8: does not trigger the
    "unused local typedefs" warning caused by the addition of
  - Wunused-local-typedefs to -Wall in g++ 4.8. See
    http://gcc.gnu.org/ml/gcc-patches/2011-07/msg02460.html
    http://gcc.gnu.org/ml/gcc-patches/2012-05/msg01388.html
  + Also compiles cleanly and builds correctly with clang++ 3.4
- Drop glucat-build-with-updated-boost.patch: incorporated
  upstream
- Implement a %%check section with included tests
- Drop conditionals solely relevant to end-of-life openSUSE
  versions
- Do not package unnecessary INSTALL file
- Update year in specfile COPYRIGHT.
* Thu Aug  1 2013 dvaleev@suse.com
- rename glucat-fix-i586-build.patch to glucat-fix-32bit-build.patch
- apply it for ppc 32Bit
* Sat Jun  8 2013 badshah400@gmail.com
- Add glucat-build-with-updated-boost.patch to fix building with
  boost > 1.50; patch came from upstream
- Include INSTALL file in package since it provides important
  information for compiling code built against glucat on
  openSUSE > 12.3.
* Tue Jan  8 2013 badshah400@gmail.com
- Update to version 0.7.1:
  + Fixes a bug which prevented compilation in the case where the
    class glucat::framed_multi<> is based on std::map.
* Thu Oct 25 2012 badshah400@gmail.com
- Add glucat-fix-i586-build.patch to fix build failures on i586.
* Thu Oct 11 2012 badshah400@gmail.com
- Update to version 0.7.0:
  + More accurate sqrt and transcendental functions and includes
    PyClical tutorials
  + The PyClical Python extension module now comes with a set of
    tutorials that guide you through working with Clifford algebra
    calculations in Python
  + The GluCat library now supports C++11, including
    <unordered_map> and <random>
  + Now has transcendental functions that are more accurate when
    used with higher precision arithmetic. This is accomplished by
    using different Pade' approximations according to
    the numerical precision needed
  + The class glucat::framed_multi<> based on hash_map or
    unordered_map now uses constructors that specify an initial
    number of buckets
  + The basis_element cache used for glucat::matrix_multi<> now
    uses pointers to matrices instead of matrices
  + The GluCat header files have been reorganized so that they now
    directly include the header files they depend on, rather than
    relying on glucat/glucat.h and glucat/glucat_imp.h to do this
  + The default options for ./configure now yield the simplest
    usable production case: ./configure without arguments with
    GluCat 0.7.0 gives the same results as
    "./configure --with-map=unordered --enable-debug=no
  - -enable-pyclical" did with GluCat 0.6.0
  + The README and INSTALL files have been completely rewritten,
    and AUTHORS has been updated.
* Sun May 13 2012 badshah400@gmail.com
- Update to version 0.6.0:
  + Includes the PyClical extension module for Python
  + Changes to the clifford_algebra<> API:
  - The real() function is now synonymous with scalar() and the
    imag() function always returns 0
  - New operators lhs | rhs and lhs |= rhs transform lhs by the
    twisted adjoint action of rhs
  - New member functions, grade() : maximum of the grades of
    each term;  pure() : pure part
  - New function complexifier(val) : square root of -1 which
    commutes with all members of the frame of the multivector
    val. The name "elliptic" is now deprecated: use
    "complexifier" instead
  - New functions sqrt(val,i,prechecked), and
    log(val,i,prechecked) : square root and logarithm of
    multivector with specified complexifier
- Split out python-glucat package with the python module
- Package is now arch dependent.
* Sun Mar 18 2012 scorot@free.fr
- add conditionnal noarch target to devel package to fix SLE build
* Thu Mar 24 2011 badshah400@gmail.com
- Initial package (version 0.5.1)
